graspologic in the wild
=======================

Below we include some examples of graspologic being used in projects. Feel free to make
a pull request if you'd like to add to this list!

Papers
""""""
* `Statistical connectomics <https://www.annualreviews.org/doi/abs/10.1146/annurev-statistics-042720-023234>`_: 
  Authors in the NeuroData group at Johns Hopkins University "provide an overview from the perspective of statistical network science of
  the kinds of models, assumptions, problems, and applications that are theoretically and 
  empirically justified for analysis of connectome data," using graspologic for most 
  analysis and examples.

* `Graph matching via optimal transport <https://arxiv.org/abs/2111.05366>`_:
  Authors in the NeuroData group improved on a state-of-the-art technique for graph matching, making the algorithm faster and more accurate on
  larger and less-correlated networks.

Blog posts
""""""""""
* `Advancing organizational science using network machine learning to measure innovation in the workplace <https://www.microsoft.com/en-us/research/blog/advancing-organizational-science-using-network-machine-learning-to-measure-innovation-in-the-workplace>`_: 
  Researchers at Microsoft Research and collaborators used tools from graspologic (network
  layout, partitioning and modularity) to understand how workplace collaboration networks
  changed during the COVID-19 pandemic.

* `NeuroData notebooks <https://docs.neurodata.io/notebooks/categories/#graspologic>`_ : 
  Check out this page to see what some of the members of the NeuroData lab are working on
  using graspologic.
